import { __decorate } from 'tslib';
import { Component, ChangeDetectionStrategy, ChangeDetectorRef, ElementRef, NgZone, NgModule } from '@angular/core';
import { fromEvent } from 'rxjs';
import { defineCustomElements } from '@julis/web-ui/loader';

/* eslint-disable */
const proxyInputs = (Cmp, inputs) => {
    const Prototype = Cmp.prototype;
    inputs.forEach(item => {
        Object.defineProperty(Prototype, item, {
            get() {
                return this.el[item];
            },
            set(val) {
                this.z.runOutsideAngular(() => (this.el[item] = val));
            }
        });
    });
};
const proxyMethods = (Cmp, methods) => {
    const Prototype = Cmp.prototype;
    methods.forEach(methodName => {
        Prototype[methodName] = function () {
            const args = arguments;
            return this.z.runOutsideAngular(() => this.el[methodName].apply(this.el, args));
        };
    });
};
const proxyOutputs = (instance, el, events) => {
    events.forEach(eventName => instance[eventName] = fromEvent(el, eventName));
};
function ProxyCmp(opts) {
    const decorator = function (cls) {
        if (opts.inputs) {
            proxyInputs(cls, opts.inputs);
        }
        if (opts.methods) {
            proxyMethods(cls, opts.methods);
        }
        return cls;
    };
    return decorator;
}

let JlButton = class JlButton {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
    }
};
JlButton.decorators = [
    { type: Component, args: [{ selector: "jl-button", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["backgroundColor", "backgroundHoverColor", "disabled", "text", "textColor", "textHoverColor"] },] }
];
JlButton.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlButton = __decorate([
    ProxyCmp({ inputs: ["backgroundColor", "backgroundHoverColor", "disabled", "text", "textColor", "textHoverColor"] })
], JlButton);
let JlCheckbox = class JlCheckbox {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
        proxyOutputs(this, this.el, ["checkedChange"]);
    }
};
JlCheckbox.decorators = [
    { type: Component, args: [{ selector: "jl-checkbox", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["checked", "color", "disabled", "text"] },] }
];
JlCheckbox.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlCheckbox = __decorate([
    ProxyCmp({ inputs: ["checked", "color", "disabled", "text"] })
], JlCheckbox);
class JlFonts {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
    }
}
JlFonts.decorators = [
    { type: Component, args: [{ selector: "jl-fonts", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>" },] }
];
JlFonts.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
let JlInput = class JlInput {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
        proxyOutputs(this, this.el, ["valueChange"]);
    }
};
JlInput.decorators = [
    { type: Component, args: [{ selector: "jl-input", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["color", "fluid", "formatter", "hint", "label", "name", "placeholder", "readonly", "type", "validator", "value"] },] }
];
JlInput.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlInput = __decorate([
    ProxyCmp({ inputs: ["color", "fluid", "formatter", "hint", "label", "name", "placeholder", "readonly", "type", "validator", "value"] })
], JlInput);
let JlLogo = class JlLogo {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
    }
};
JlLogo.decorators = [
    { type: Component, args: [{ selector: "jl-logo", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["backgroundColor", "gliederung", "logoColor", "textColor"] },] }
];
JlLogo.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlLogo = __decorate([
    ProxyCmp({ inputs: ["backgroundColor", "gliederung", "logoColor", "textColor"] })
], JlLogo);
let JlProgressBar = class JlProgressBar {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
        proxyOutputs(this, this.el, ["completed"]);
    }
};
JlProgressBar.decorators = [
    { type: Component, args: [{ selector: "jl-progress-bar", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["color", "loadingText", "maxValue", "textColor", "type", "value"] },] }
];
JlProgressBar.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlProgressBar = __decorate([
    ProxyCmp({ inputs: ["color", "loadingText", "maxValue", "textColor", "type", "value"] })
], JlProgressBar);
let JlTitle = class JlTitle {
    constructor(c, r, z) {
        this.z = z;
        c.detach();
        this.el = r.nativeElement;
    }
};
JlTitle.decorators = [
    { type: Component, args: [{ selector: "jl-title", changeDetection: ChangeDetectionStrategy.OnPush, template: "<ng-content></ng-content>", inputs: ["backgroundColor", "subtext", "text", "textColor"] },] }
];
JlTitle.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: NgZone }
];
JlTitle = __decorate([
    ProxyCmp({ inputs: ["backgroundColor", "subtext", "text", "textColor"] })
], JlTitle);

defineCustomElements(window);
const DECLARATIONS = [
    JlFonts,
    JlLogo,
    JlTitle,
    JlButton,
    JlCheckbox,
    JlInput,
    JlProgressBar,
];
class WebUiAngularModule {
}
WebUiAngularModule.decorators = [
    { type: NgModule, args: [{
                declarations: DECLARATIONS,
                exports: DECLARATIONS,
                imports: [],
                providers: [],
            },] }
];

/*
 * Public API Surface of web-ui-angular
 */

/**
 * Generated bundle index. Do not edit.
 */

export { JlButton, JlCheckbox, JlFonts, JlInput, JlLogo, JlProgressBar, JlTitle, WebUiAngularModule, ProxyCmp as ɵa };
//# sourceMappingURL=julis-web-ui-angular.js.map
